aboutsummaryrefslogtreecommitdiffstats
path: root/PolicyEngineAPI/src/main/java/org/onap/policy/api/ConfigRequestParameters.java
diff options
context:
space:
mode:
Diffstat (limited to 'PolicyEngineAPI/src/main/java/org/onap/policy/api/ConfigRequestParameters.java')
-rw-r--r--PolicyEngineAPI/src/main/java/org/onap/policy/api/ConfigRequestParameters.java32
1 files changed, 27 insertions, 5 deletions
diff --git a/PolicyEngineAPI/src/main/java/org/onap/policy/api/ConfigRequestParameters.java b/PolicyEngineAPI/src/main/java/org/onap/policy/api/ConfigRequestParameters.java
index cdee9672b..dcdc17802 100644
--- a/PolicyEngineAPI/src/main/java/org/onap/policy/api/ConfigRequestParameters.java
+++ b/PolicyEngineAPI/src/main/java/org/onap/policy/api/ConfigRequestParameters.java
@@ -31,7 +31,7 @@ import java.util.UUID;
*/
public class ConfigRequestParameters {
private String policyName;
- private String onapComponentName;
+ private String onapName;
private String configName;
private Map<String,String> configAttributes;
private UUID requestID;
@@ -49,13 +49,24 @@ public class ConfigRequestParameters {
/**
* Sets the ONAP Component Name of the Config policy which needs to be retrieved.
*
* @param onapComponentName the <code>String</code> format of the onapComponentName whose configuration is required.
*/
- public void setOnapName(String onapComponentName){
- this.onapComponentName = onapComponentName;
+ public void setOnapName(String onapName){
+ this.onapName = onapName;
}
/**
+ * Sets the ONAP Component Name of the Config policy which needs to be retrieved.
+ *
+ * @param ecompName the <code>String</code> format of the onapName whose configuration is required.
+ * @deprecated use {@link #setOnapName(String)} instead.
+ */
+ @Deprecated
+ public void setEcompName(String ecompName){
+ this.onapName = ecompName;
+ }
+
+ /**
* Sets the Config Name of the Config policy which needs to be retrieved.
*
* @param configName the <code>String</code> format of the configurationName whose configuration is required.
@@ -97,10 +108,21 @@ public class ConfigRequestParameters {
* @return <code>String</code> format of the ONAP Component Name.
*/
public String getOnapName(){
- return onapComponentName;
+ return onapName;
}
/**
+ * Gets the ONAP Component Name of the Request Parameters.
+ *
+ * @return <code>String</code> format of the ONAP Component Name.
+ * @deprecated use {@link #getOnapName()} instead.
+ */
+ @Deprecated
+ public String getEcompName(){
+ return onapName;
+ }
+
+ /**
* Gets the Config name of the Request Parameters.
*
* @return <code>String</code> format of the Config Name.
@@ -49,13 +49,24 @@ public class ConfigRequestParameters {
* Sets the ONAP Component Name of the Config policy which needs to be retrieved.
*
- * @param onapComponentName the <code>String</code> format of the onapComponentName whose configuration is required.
+ * @param onapName the <code>String</code> format of the onapName whose configuration is required.
*/